==> otyacraftengine-fabric-3.3.0-pre.3-sources.jar: dev/felnull/otyacraftengine/fabric/data/provider/WrappedFabricItemTagProvider.java <==
package dev.felnull.otyacraftengine.fabric.data.provider;

import dev.felnull.otyacraftengine.data.provider.IntrinsicHolderTagsProviderWrapper;
import dev.felnull.otyacraftengine.data.provider.ItemTagProviderWrapper;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;


public class WrappedFabricItemTagProvider extends FabricTagProvider.ItemTagProvider {
    private final ItemTagProviderWrapper tagProviderWrapper;

    public WrappedFabricItemTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> completableFuture, @Nullable BlockTagProvider blockTagProvider, ItemTagProviderWrapper tagProviderWrapper) {
        super(output, completableFuture, blockTagProvider);
        this.tagProviderWrapper = tagProviderWrapper;
    }

    @Override
    protected void method_10514(class_7225.class_7874 arg) {
        this.tagProviderWrapper.generateTag(new ItemTagProviderAccessImpl());
    }


    private class ItemTagProviderAccessImpl implements ItemTagProviderWrapper.ItemTagProviderAccess {
        @Override
        public void copy(class_6862<class_2248> blockTag, class_6862<class_1792> itemTag) {
            WrappedFabricItemTagProvider.this.copy(blockTag, itemTag);
        }

        @Override
        public IntrinsicHolderTagsProviderWrapper.IntrinsicTagAppenderWrapper<class_1792> tag(class_6862<class_1792> tagKey) {
            return new WrappedFabricIntrinsicHolderTagsProvider.IntrinsicHolderTagAppenderWrapperImpl<>(WrappedFabricItemTagProvider.this.method_10512(tagKey), tagProviderWrapper);
        }
    }
}

==> otyacraftengine-fabric-3.5.0-pre.11-sources.jar: dev/felnull/otyacraftengine/fabric/data/provider/WrappedFabricItemTagProvider.java <==
package dev.felnull.otyacraftengine.fabric.data.provider;

import dev.felnull.otyacraftengine.data.provider.IntrinsicHolderTagsProviderWrapper;
import dev.felnull.otyacraftengine.data.provider.ItemTagProviderWrapper;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;


public class WrappedFabricItemTagProvider extends FabricTagProvider.ItemTagProvider {
    private final ItemTagProviderWrapper tagProviderWrapper;

    public WrappedFabricItemTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> completableFuture, @Nullable BlockTagProvider blockTagProvider, ItemTagProviderWrapper tagProviderWrapper) {
        super(output, completableFuture, blockTagProvider);
        this.tagProviderWrapper = tagProviderWrapper;
    }

    @Override
    protected void addTags(class_7225.class_7874 arg) {
        this.tagProviderWrapper.generateTag(new ItemTagProviderAccessImpl());
    }


    private class ItemTagProviderAccessImpl implements ItemTagProviderWrapper.ItemTagProviderAccess {
        @Override
        public void copy(class_6862<class_2248> blockTag, class_6862<class_1792> itemTag) {
            WrappedFabricItemTagProvider.this.copy(blockTag, itemTag);
        }

        @Override
        public IntrinsicHolderTagsProviderWrapper.IntrinsicTagAppenderWrapper<class_1792> tag(class_6862<class_1792> tagKey) {
            return new WrappedFabricIntrinsicHolderTagsProvider.IntrinsicHolderTagAppenderWrapperImpl<>(WrappedFabricItemTagProvider.this.tag(tagKey), tagProviderWrapper);
        }
    }
}
